==> jc-1.4.0.tar.gz: soot/tagkit/StringConstantValueTag.h <==
// public class soot.tagkit.StringConstantValueTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class ba90f218e62b80e1 soot_tagkit_StringConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_StringConstantValueTag_H_
#define _JC_soot_tagkit_StringConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_StringConstantValueTag$sub_refs	_jc_soot_tagkit_StringConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$sub_nonrefs	_jc_soot_tagkit_StringConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$refs	_jc_soot_tagkit_StringConstantValueTag$refs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$nonrefs	_jc_soot_tagkit_StringConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$object	_jc_soot_tagkit_StringConstantValueTag$object;

typedef const struct _jc_soot_tagkit_StringConstantValueTag$vmethods	_jc_soot_tagkit_StringConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_StringConstantValueTag$vtable	_jc_soot_tagkit_StringConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_StringConstantValueTag$vtype	_jc_soot_tagkit_StringConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_StringConstantValueTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_tagkit_StringConstantValueTag$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061(_jc_env *, struct _jc_soot_tagkit_StringConstantValueTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_StringConstantValueTag$method_info$getStringValue$3b6fd4874b831061;

// Virtual methods structure
struct _jc_soot_tagkit_StringConstantValueTag$vmethods {
	struct _jc_java_lang_String$object	*(*getStringValue$3b6fd4874b831061)(_jc_env *, struct _jc_soot_tagkit_StringConstantValueTag$object *);
};

// Vtable
struct _jc_soot_tagkit_StringConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_StringConstantValueTag$vmethods	soot_tagkit_StringConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_StringConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_StringConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_StringConstantValueTag$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_StringConstantValueTag$refs {
    _jc_soot_tagkit_StringConstantValueTag$sub_refs	soot_tagkit_StringConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_StringConstantValueTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_StringConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_StringConstantValueTag$sub_nonrefs	soot_tagkit_StringConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_StringConstantValueTag$object {
	_jc_soot_tagkit_StringConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_StringConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_StringConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_StringConstantValueTag$vtype _jc_soot_tagkit_StringConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_StringConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_StringConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_StringConstantValueTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/StringConstantValueTag.h <==
// public class soot.tagkit.StringConstantValueTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class ba90f218e62b80e1 soot_tagkit_StringConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_StringConstantValueTag_H_
#define _JC_soot_tagkit_StringConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_StringConstantValueTag$sub_refs	_jc_soot_tagkit_StringConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$sub_nonrefs	_jc_soot_tagkit_StringConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$refs	_jc_soot_tagkit_StringConstantValueTag$refs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$nonrefs	_jc_soot_tagkit_StringConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_StringConstantValueTag$object	_jc_soot_tagkit_StringConstantValueTag$object;

typedef const struct _jc_soot_tagkit_StringConstantValueTag$vmethods	_jc_soot_tagkit_StringConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_StringConstantValueTag$vtable	_jc_soot_tagkit_StringConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_StringConstantValueTag$vtype	_jc_soot_tagkit_StringConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_StringConstantValueTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_tagkit_StringConstantValueTag$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061(_jc_env *, struct _jc_soot_tagkit_StringConstantValueTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_StringConstantValueTag$method_info$getStringValue$3b6fd4874b831061;

// Virtual methods structure
struct _jc_soot_tagkit_StringConstantValueTag$vmethods {
	struct _jc_java_lang_String$object	*(*getStringValue$3b6fd4874b831061)(_jc_env *, struct _jc_soot_tagkit_StringConstantValueTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_StringConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_StringConstantValueTag$vmethods	soot_tagkit_StringConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_StringConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_StringConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_StringConstantValueTag$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_StringConstantValueTag$refs {
    _jc_soot_tagkit_StringConstantValueTag$sub_refs	soot_tagkit_StringConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_StringConstantValueTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_StringConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_StringConstantValueTag$sub_nonrefs	soot_tagkit_StringConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_StringConstantValueTag$object {
	_jc_soot_tagkit_StringConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_StringConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_StringConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_StringConstantValueTag$vtype _jc_soot_tagkit_StringConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_StringConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_StringConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_StringConstantValueTag_H_ */
